/*
 * Copyright (C) 2005 by the gtk2-perl team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: gstinterfacesperl.h,v 1.2 2006/01/24 19:53:42 kaffeetisch Exp $
 */

#ifndef _GSTINTERFACES2PERL_H_
#define _GSTINTERFACES2PERL_H_

#include <gst2perl.h>

#include <gst/interfaces/propertyprobe.h>
#include <gst/interfaces/xoverlay.h>

#include "gstinterfacesperl-autogen.h"

#endif /* _GSTINTERFACES2PERL_H_ */
